// -----------------------------------------------------------------------
// QA methods
// -----------------------------------------------------------------------

import { ValidatedMethod } from "../lib/validated-method.js";

/**
 * debugError is used by QA to generate custom error messages for debugging.
 *
 * @type {ValidatedMethod}
 */
export const debugError = new ValidatedMethod({
  name: "error",
  run: (msg, { guardian }) => guardian.setLastError(msg),
});

/**
 * debugGetLastError is used by QA to retrieve error messages for debugging.
 *
 * @type {ValidatedMethod}
 */
export const debugGetLastError = new ValidatedMethod({
  name: "debug.getLastError",
  run: (_, { guardian }) => {
    return Promise.resolve(guardian.getLastError());
  },
});

export const debugGetStatus = new ValidatedMethod({
  name: "debug.getStatus",
  run: (_, { guardian }) => {
    return Promise.resolve(guardian.getStatus());
  },
});

export const subscriptionsGet = new ValidatedMethod({
  name: "subscriptions.get",
  run: async (msg, { blocker }) => {
    const ignoreDisabled = msg && msg.ignoreDisabled;
    const disabledFilters = msg && msg.disabledFilters;

    return blocker.subscriptionsGet({ ignoreDisabled, disabledFilters });
  },
});

export const subscriptionsRemove = new ValidatedMethod({
  name: "subscriptions.remove",
  run: ({ url }, { blocker }) => blocker.subscriptionsRemove({ url }),
});

export const filtersGet = new ValidatedMethod({
  name: "filters.get",
  run: (_, { blocker }) => blocker.filtersGet(),
});

export const filtersRemove = new ValidatedMethod({
  name: "filters.remove",
  run: ({ text }, { blocker }) => blocker.filtersRemove({ text }),
});

export const filtersImportRaw = new ValidatedMethod({
  name: "filters.importRaw",
  run: ({ text, origin }, { blocker }) =>
    blocker.filtersImportRaw({ text, origin }),
});
